@@ -7,7 +7,7 @@ import decimal
 
 from simplegeneric import generic
 
-from wsme.rest import RestProtocol
+from wsme.protocols.rest import RestProtocol
 import wsme.types
 
 try:
@@ -34,8 +34,8 @@ def tojson(datatype, value):
     """
     if wsme.types.iscomplex(datatype):
         d = dict()
-        for name, attr in wsme.types.list_attributes(datatype):
-            d[name] = tojson(attr.datatype, getattr(value, name))
+        for attr in wsme.types.list_attributes(datatype):
+            d[attr.key] = tojson(attr.datatype, getattr(value, attr.key))
         return d
     return value
 
@@ -65,11 +65,6 @@ def datetime_tojson(datatype, value):
     return value.isoformat()
 
 
-@tojson.when_object(wsme.types.binary)
-def datetime_tojson(datatype, value):
-    return base64.encodestring(value)
-
-
 @generic
 def fromjson(datatype, value):
     """
@@ -91,9 +86,10 @@ def fromjson(datatype, value):
         return None
     if wsme.types.iscomplex(datatype):
         obj = datatype()
-        for name, attrdef in wsme.types.list_attributes(datatype):
-            if name in value:
-                setattr(obj, name, fromjson(attrdef.datatype, value[name]))
+        for attrdef in wsme.types.list_attributes(datatype):
+            if attrdef.key in value:
+                setattr(obj, attrdef.key,
+                        fromjson(attrdef.datatype, value[attrdef.key]))
         return obj
     return value
 
@@ -123,11 +119,6 @@ def time_fromjson(datatype, value):
     return datetime.datetime.strptime(value, '%Y-%m-%dT%H:%M:%S')
 
 
-@fromjson.when_object(wsme.types.binary)
-def binary_fromjson(datatype, value):
-    return base64.decodestring(value)
-
-
 class RestJsonProtocol(RestProtocol):
     """
     REST+Json protocol.
