@@ -8,7 +8,7 @@ except ImportError:
 
 from simplegeneric import generic
 
-from wsme.rest import RestProtocol
+from wsme.protocols.rest import RestProtocol
 from wsme.exc import *
 import wsme.types
 
@@ -42,9 +42,13 @@ def toxml(datatype, key, value):
     if value is None:
         el.set('nil', 'true')
     else:
-        if wsme.types.iscomplex(datatype):
-            for key, attrdef in datatype._wsme_attributes:
-                el.append(toxml(attrdef.datatype, key, getattr(value, key)))
+        if wsme.types.isusertype(datatype):
+            return toxml(datatype.basetype,
+                            key, datatype.tobasetype(value))
+        elif wsme.types.iscomplex(datatype):
+            for attrdef in datatype._wsme_attributes:
+                el.append(toxml(attrdef.datatype, attrdef.key,
+                                getattr(value, attrdef.key)))
         else:
             el.text = unicode(value)
     return el
@@ -71,12 +75,15 @@ def fromxml(datatype, element):
     """
     if element.get('nil', False):
         return None
+    if wsme.types.isusertype(datatype):
+        return datatype.frombasetype(
+                fromxml(datatype.basetype, element))
     if wsme.types.iscomplex(datatype):
         obj = datatype()
-        for key, attrdef in datatype._wsme_attributes:
-            sub = element.find(key)
+        for attrdef in datatype._wsme_attributes:
+            sub = element.find(attrdef.key)
             if sub is not None:
-                setattr(obj, key, fromxml(attrdef.datatype, sub))
+                setattr(obj, attrdef.key, fromxml(attrdef.datatype, sub))
         return obj
     return datatype(element.text)
 
@@ -122,16 +129,6 @@ def datetime_toxml(datatype, key, value):
     return el
 
 
-@toxml.when_object(wsme.types.binary)
-def binary_toxml(datatype, key, value):
-    el = et.Element(key)
-    if value is None:
-        el.set('nil', 'true')
-    else:
-        el.text = base64.encodestring(value)
-    return el
-
-
 @fromxml.when_type(list)
 def array_fromxml(datatype, element):
     if element.get('nil') == 'true':
@@ -159,11 +156,6 @@ def datetime_fromxml(datatype, element):
     return datetime.datetime.strptime(element.text, '%Y-%m-%dT%H:%M:%S')
 
 
-@fromxml.when_object(wsme.types.binary)
-def binary_fromxml(datatype, element):
-    return base64.decodestring(element.text)
-
-
 class RestXmlProtocol(RestProtocol):
     """
     REST+XML protocol.
@@ -186,7 +178,8 @@ class RestXmlProtocol(RestProtocol):
         return dict((sub.tag, sub) for sub in et.fromstring(body))
 
     def encode_result(self, context, result):
-        return et.tostring(toxml(context.funcdef.return_type, 'result', result))
+        return et.tostring(
+            toxml(context.funcdef.return_type, 'result', result))
 
     def encode_error(self, context, errordetail):
         el = et.Element('error')
