@@ -1,10 +1,7 @@
 name = "WSME"
-version = "0.1.1"
+version = "0.2.0"
 
 description = "Web Services Made Easy"
-long_description = """
-Web Service Made Easy is a pure-wsgi and modular rewrite of TGWebServices.
-"""
 
 author = "Christophe de Vienne"
 email = "python-wsme@googlegroups.com"
